package net.geraldloeffler.tasktracker2006.domain;

import java.io.Serializable;
import java.util.Date;
import javax.xml.bind.annotation.AccessType;
import javax.xml.bind.annotation.XmlAccessorType;

/**
 * Non-persistent Entry domain class mapped to XML via JAXB annotations.
 * An Entry relates to exactly one Task.
 * 
 * @author Gerald Loeffler
 */
@XmlAccessorType(AccessType.FIELD)
public class Entry implements Serializable {
  private static final long serialVersionUID = 1L;
  
  private Integer id;
  private String  description;
  private Date    from;
  private Date    to;
  private String  userName;
  private Task    task;

  /** Required no-arg constructor (but package-scoped) */
  Entry() {}

  /** Minimal constructor */
  public Entry(Task task, Date from, String userName) {
    setTask(task);
    setFrom(from);
    setUserName(userName);
  }

  public Integer getId() {
    return id;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public Date getFrom() {
    return from;
  }

  private void setFrom(Date from) {
    if (from == null) throw new IllegalArgumentException("from is null");
    this.from = from;
  }

  public Date getTo() {
    return to;
  }

  public void setTo(Date to) {
    if (to != null && to.before(from)) throw new IllegalArgumentException(
        "to before from");
    this.to = to;
  }

  public String getUserName() {
    return userName;
  }

  private void setUserName(String userName) {
    if (userName == null) throw new IllegalArgumentException("userName is null");
    this.userName = userName;
  }

  public Task getTask() {
    return task;
  }

  private void setTask(Task task) {
    if (task == null) throw new IllegalArgumentException("task is null");
    this.task = task;
  }

  @Override
  public String toString() {
    return this.getClass().getSimpleName() + "[id=" + getId() + "]";
  }  
}
