package net.geraldloeffler.tasktracker2006.webui.util;

import javax.naming.InitialContext;

/**
 * Helps looking up objects from the service layer.
 * 
 * In a fully Java EE 5 compliant web container dependency injection using the
 * EJB annotation would work as expected and this class were not needed. In
 * JBoss's Tomcat 5.5, however, we need to do an explicit JNDI lookup instead,
 * using a JBoss-specific JNDI name for the local interface of the session bean
 * in the service layer'
 * 
 * @author Gerald Loeffler
 */
public class ServiceLookup {
  private static final String EAR_NAME                = "tasktracker";
  private static final String ENTRY_SERVICE_JNDI_NAME = EAR_NAME + "/EntryServiceBean/local";
  private static final String TASK_SERVICE_JNDI_NAME  = EAR_NAME + "/TaskServiceBean/local";
/*
  public static EntryService entryService() {
    return (EntryService) lookup(ENTRY_SERVICE_JNDI_NAME);
  }

  public static TaskService taskService() {
    return (TaskService) lookup(TASK_SERVICE_JNDI_NAME);
  }
*/
  private static Object lookup(String jndiName) {
    Object o;
    try {
      o = new InitialContext().lookup(jndiName);
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
    if (o == null) throw new RuntimeException("can't find object with JNDI name " + jndiName);
    return o;
  }
}
